summaryrefslogtreecommitdiff
path: root/sw/inc/section.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/section.hxx')
-rw-r--r--sw/inc/section.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/inc/section.hxx b/sw/inc/section.hxx
index f37600f056d4..1649ffe5e978 100644
--- a/sw/inc/section.hxx
+++ b/sw/inc/section.hxx
@@ -296,7 +296,7 @@ public:
TYPEINFO_OVERRIDE(); // Already contained in base class client.
virtual ~SwSectionFormat();
// Deletes all Frms in aDepend (Frms are recognized via PTR_CAST).
virtual void DelFrms() SAL_OVERRIDE;
// Creates views.
@@ -368,7 +368,7 @@ inline SwSectionFormat* SwSectionFormat::GetParent() const
{
SwSectionFormat* pRet = 0;
if( GetRegisteredIn() )
- pRet = const_cast<SwSectionFormat*>(PTR_CAST( SwSectionFormat, GetRegisteredIn() ));
+ pRet = const_cast<SwSectionFormat*>(dynamic_cast< const SwSectionFormat* >( GetRegisteredIn() ));
return pRet;
}
@@ -296,7 +296,7 @@ public:
TYPEINFO_OVERRIDE(); // Already contained in base class client.
virtual ~SwSectionFormat();
- // Deletes all Frms in aDepend (Frms are recognized via PTR_CAST).
+ // Deletes all Frms in aDepend (Frms are recognized via dynamic_cast).
virtual void DelFrms() SAL_OVERRIDE;
// Creates views.